@@ -67,17 +67,10 @@ class PostEndpoints:
             "Communicationlanguage": data["language"],
             "Nationality": data["nationality"],
             "Title": data["title"],
-            "Gender": data["gender"]
+            "Gender": data["gender"],
+            "ExternalEmployeesubgroup": data['external_employee_subgroup']
         }
 
-        # Add fields that you want to update a dict (adding to body itself is too much text)
-        fields_to_update = {}
-        fields_to_update.update({"ExternalEmployeesubgroup": data['external_employee_subgroup']}) if 'external_employee_subgroup' in data else fields_to_update
-
-        # Update the request body with update fields
-        fields_to_update.update(overload_fields) if overload_fields is not None else ''
-        base_body.update(fields_to_update)
-
         # Update the request body with update fields
         response = self.base_class.post_data(uri='MasterActionPost/*', data=base_body, return_key='Employeenumber')
         return response
@@ -376,4 +369,35 @@ class PostEndpoints:
         base_body.update(fields_to_update)
 
         response = self.base_class.post_data(uri='PowersAttorneyPost/*', data=base_body, return_key=None)
+        return response
+
+    def post_absence(self, data: dict):
+        """
+        Post Absence data to SAP
+        :param data: Fields that are allowed are listed in allowed fields array.
+        {
+        "Afasemployeenumber" : "70913119",
+        "Employeenumber" : "00000000",
+        "Startdate" : "2022-01-01",
+        "Enddate" : "2022-01-01",
+        "AbsenceType" : "0200",
+        "AbsenceHours" : "11.00"
+        }
+        """
+
+        allowed_fields = []
+        required_fields = ['employee_id', 'date_of_absence', 'type_of_hours_code', 'hours']
+
+        self.__check_fields(data=data, required_fields=required_fields, allowed_fields=allowed_fields)
+
+        base_body = {
+            "Afasemployeenumber": data["employee_id"],
+            "Employeenumber": "00000000",
+            "Startdate": data["date_of_absence"],
+            "Enddate": data["date_of_absence"],
+            "AbsenceType": data["type_of_hours_code"],
+            "AbsenceHours": data["hours"]
+            }
+
+        response = self.base_class.post_data(uri='AbsencePost/*', data=base_body)
         return response
\ No newline at end of file
